EnrolledService

Struct EnrolledService 

#[non_exhaustive]
pub struct EnrolledService { pub cloud_product: String, pub enrollment_level: EnrollmentLevel, /* private fields */ }
Represents the enrollment of a cloud resource into a specific service.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
cloud_product: String

The product for which Access Approval will be enrolled. Allowed values are listed below (case-sensitive):

  • all
  • GA
  • App Engine
  • BigQuery
  • Cloud Bigtable
  • Cloud Key Management Service
  • Compute Engine
  • Cloud Dataflow
  • Cloud Dataproc
  • Cloud DLP
  • Cloud EKM
  • Cloud HSM
  • Cloud Identity and Access Management
  • Cloud Logging
  • Cloud Pub/Sub
  • Cloud Spanner
  • Cloud SQL
  • Cloud Storage
  • Google Kubernetes Engine
  • Organization Policy Serivice
  • Persistent Disk
  • Resource Manager
  • Secret Manager
  • Speaker ID

Note: These values are supported as input for legacy purposes, but will not be returned from the API.

  • all
  • ga-only
  • appengine.googleapis.com
  • bigquery.googleapis.com
  • bigtable.googleapis.com
  • container.googleapis.com
  • cloudkms.googleapis.com
  • cloudresourcemanager.googleapis.com
  • cloudsql.googleapis.com
  • compute.googleapis.com
  • dataflow.googleapis.com
  • dataproc.googleapis.com
  • dlp.googleapis.com
  • iam.googleapis.com
  • logging.googleapis.com
  • orgpolicy.googleapis.com
  • pubsub.googleapis.com
  • spanner.googleapis.com
  • secretmanager.googleapis.com
  • speakerid.googleapis.com
  • storage.googleapis.com

Calls to UpdateAccessApprovalSettings using ‘all’ or any of the XXX.googleapis.com will be translated to the associated product name (‘all’, ‘App Engine’, etc.).

Note: ‘all’ will enroll the resource in all products supported at both ‘GA’ and ‘Preview’ levels.

More information about levels of support is available at https://cloud.google.com/access-approval/docs/supported-services

enrollment_level: EnrollmentLevel

The enrollment level of the service.

Implementations

Source

impl EnrolledService

pub fn new() -> Self

pub fn set_cloud_product<T: Into<String>>(self, v: T) -> Self

Sets the value of cloud_product.

Example
let x = EnrolledService::new().set_cloud_product("example");
pub fn set_enrollment_level<T: Into<EnrollmentLevel>>(self, v: T) -> Self

Sets the value of enrollment_level.

Example
use google_cloud_accessapproval_v1::model::EnrollmentLevel;
let x0 = EnrolledService::new().set_enrollment_level(EnrollmentLevel::BlockAll);