#[non_exhaustive]pub struct ListApprovalRequestsMessage {
pub parent: String,
pub filter: String,
pub page_size: i32,
pub page_token: String,
/* private fields */
}Expand description
Request to list approval requests.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringThe parent resource. This may be “projects/{project}”, “folders/{folder}”, or “organizations/{organization}”.
filter: StringA filter on the type of approval requests to retrieve. Must be one of the following values:
- [not set]: Requests that are pending or have active approvals.
- ALL: All requests.
- PENDING: Only pending requests.
- ACTIVE: Only active (i.e. currently approved) requests.
- DISMISSED: Only requests that have been dismissed, or requests that are not approved and past expiration.
- EXPIRED: Only requests that have been approved, and the approval has expired.
- HISTORY: Active, dismissed and expired requests.
page_size: i32Requested page size.
page_token: StringA token identifying the page of results to return.
Implementations
Sourceimpl ListApprovalRequestsMessage
impl ListApprovalRequestsMessage
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
ⓘ
let x = ListApprovalRequestsMessage::new().set_page_token("example");Trait Implementations
Sourceimpl Clone for ListApprovalRequestsMessage
impl Clone for ListApprovalRequestsMessage
Sourcefn clone(&self) -> ListApprovalRequestsMessage
fn clone(&self) -> ListApprovalRequestsMessage
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListApprovalRequestsMessage
impl Debug for ListApprovalRequestsMessage
Sourceimpl Default for ListApprovalRequestsMessage
impl Default for ListApprovalRequestsMessage
Sourcefn default() -> ListApprovalRequestsMessage
fn default() -> ListApprovalRequestsMessage
Returns the “default value” for a type. Read more
impl StructuralPartialEq for ListApprovalRequestsMessage