#[non_exhaustive]pub struct ListApprovalRequestsResponse {
pub approval_requests: Vec<ApprovalRequest>,
pub next_page_token: String,
/* private fields */
}Expand description
Response to listing of ApprovalRequest objects.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.approval_requests: Vec<ApprovalRequest>Approval request details.
next_page_token: StringToken to retrieve the next page of results, or empty if there are no more.
Implementations
Sourceimpl ListApprovalRequestsResponse
impl ListApprovalRequestsResponse
pub fn new() -> Self
Sourcepub fn set_approval_requests<T, V>(self, v: T) -> Self
pub fn set_approval_requests<T, V>(self, v: T) -> Self
Sets the value of approval_requests.
Example
ⓘ
use google_cloud_accessapproval_v1::model::ApprovalRequest;
let x = ListApprovalRequestsResponse::new()
.set_approval_requests([
ApprovalRequest::default()/* use setters */,
ApprovalRequest::default()/* use (different) setters */,
]);Sourcepub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_next_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of next_page_token.
Example
ⓘ
let x = ListApprovalRequestsResponse::new().set_next_page_token("example");Trait Implementations
Sourceimpl Clone for ListApprovalRequestsResponse
impl Clone for ListApprovalRequestsResponse
Sourcefn clone(&self) -> ListApprovalRequestsResponse
fn clone(&self) -> ListApprovalRequestsResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ListApprovalRequestsResponse
impl Debug for ListApprovalRequestsResponse
Sourceimpl Default for ListApprovalRequestsResponse
impl Default for ListApprovalRequestsResponse
Sourcefn default() -> ListApprovalRequestsResponse
fn default() -> ListApprovalRequestsResponse
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for ListApprovalRequestsResponse
impl PartialEq for ListApprovalRequestsResponse
Sourcefn eq(&self, other: &ListApprovalRequestsResponse) -> bool
fn eq(&self, other: &ListApprovalRequestsResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for ListApprovalRequestsResponse