#[non_exhaustive]pub struct ResourceProperties {
pub excludes_descendants: bool,
/* private fields */
}Expand description
The properties associated with the resource of the request.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.excludes_descendants: boolWhether an approval will exclude the descendants of the resource being requested.
Implementations
Sourceimpl ResourceProperties
impl ResourceProperties
pub fn new() -> Self
Sourcepub fn set_excludes_descendants<T: Into<bool>>(self, v: T) -> Self
pub fn set_excludes_descendants<T: Into<bool>>(self, v: T) -> Self
Sets the value of excludes_descendants.
Example
ⓘ
let x = ResourceProperties::new().set_excludes_descendants(true);Trait Implementations
Sourceimpl Clone for ResourceProperties
impl Clone for ResourceProperties
Sourcefn clone(&self) -> ResourceProperties
fn clone(&self) -> ResourceProperties
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResourceProperties
impl Debug for ResourceProperties
Sourceimpl Default for ResourceProperties
impl Default for ResourceProperties
Sourcefn default() -> ResourceProperties
fn default() -> ResourceProperties
Returns the “default value” for a type. Read more
Sourceimpl Message for ResourceProperties
impl Message for ResourceProperties
Sourceimpl PartialEq for ResourceProperties
impl PartialEq for ResourceProperties
impl StructuralPartialEq for ResourceProperties