#[non_exhaustive]pub struct SignatureInfo {
pub signature: Bytes,
pub verification_info: Option<VerificationInfo>,
/* private fields */
}Expand description
Information about the digital signature of the resource.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.signature: BytesThe digital signature.
verification_info: Option<VerificationInfo>How this signature may be verified.
Implementations
Sourceimpl SignatureInfo
impl SignatureInfo
pub fn new() -> Self
Sourcepub fn set_signature<T: Into<Bytes>>(self, v: T) -> Self
pub fn set_signature<T: Into<Bytes>>(self, v: T) -> Self
Sourcepub fn set_verification_info<T: Into<Option<VerificationInfo>>>(
self,
v: T,
) -> Self
pub fn set_verification_info<T: Into<Option<VerificationInfo>>>( self, v: T, ) -> Self
Sets the value of verification_info.
Note that all the setters affecting verification_info are mutually
exclusive.
Example
use google_cloud_accessapproval_v1::model::signature_info::VerificationInfo;
let x = SignatureInfo::new().set_verification_info(Some(VerificationInfo::GooglePublicKeyPem("example".to_string())));Sourcepub fn google_public_key_pem(&self) -> Option<&String>
pub fn google_public_key_pem(&self) -> Option<&String>
The value of verification_info
if it holds a GooglePublicKeyPem, None if the field is not set or
holds a different branch.
Sourcepub fn set_google_public_key_pem<T: Into<String>>(self, v: T) -> Self
pub fn set_google_public_key_pem<T: Into<String>>(self, v: T) -> Self
Sets the value of verification_info
to hold a GooglePublicKeyPem.
Note that all the setters affecting verification_info are
mutually exclusive.
Example
let x = SignatureInfo::new().set_google_public_key_pem("example");
assert!(x.google_public_key_pem().is_some());
assert!(x.customer_kms_key_version().is_none());Sourcepub fn customer_kms_key_version(&self) -> Option<&String>
pub fn customer_kms_key_version(&self) -> Option<&String>
The value of verification_info
if it holds a CustomerKmsKeyVersion, None if the field is not set or
holds a different branch.
Sourcepub fn set_customer_kms_key_version<T: Into<String>>(self, v: T) -> Self
pub fn set_customer_kms_key_version<T: Into<String>>(self, v: T) -> Self
Sets the value of verification_info
to hold a CustomerKmsKeyVersion.
Note that all the setters affecting verification_info are
mutually exclusive.
Example
let x = SignatureInfo::new().set_customer_kms_key_version("example");
assert!(x.customer_kms_key_version().is_some());
assert!(x.google_public_key_pem().is_none());Trait Implementations
Sourceimpl Clone for SignatureInfo
impl Clone for SignatureInfo
Sourcefn clone(&self) -> SignatureInfo
fn clone(&self) -> SignatureInfo
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more